@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
 version: 1.4.12
-id: yesod-auth-1.4.12-bd2dbd422b8b288b6daf1ac8f5cb89f3
-key: yesod_4yiAqaS3YWP7Fdn0pILrAk
+id: yesod-auth-1.4.12-7be9649dc74d6f1258f9690098986b59
+key: yesod_6xAUGfle6NtFfyUrwbofCf
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -23,10 +23,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.12
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.12
-hs-libraries: HSyesod-auth-1.4.12-4yiAqaS3YWP7Fdn0pILrAk
+hs-libraries: HSyesod-auth-1.4.12-6xAUGfle6NtFfyUrwbofCf
 depends:
-    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
-    authenticate-1.3.3-53ea91e5c026eab440060c4bf4b2b35c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    authenticate-1.3.3-0fee63ddb48a70d3e37f4eef5824beb7
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -36,35 +36,35 @@ depends:
     blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
-    conduit-extra-1.1.11-b294a7608a3a066998e74974ec65ff9b
+    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
+    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
-    email-validate-2.2.0-894e6c8f7fbbeb1604af196a15c5e993
+    email-validate-2.2.0-ae0abf871e42011586547a4481d3ce69
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
     http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
-    http-conduit-2.1.8-76c320bb56047f4b6951f7d6a8e71998
+    http-conduit-2.1.8-288436503dec7c7ed70373ac0e4730a6
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     mime-mail-0.4.11-159ba13f631e4ac9bb3254d1bcac4f3d
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     nonce-1.0.2-ba2a4fc59a4ebf1fc9363b2dcb9c988b
-    persistent-2.2.4-a4a8972281cfa07170d8ccc96de1b890
-    persistent-template-2.1.5-71ed59f649efc8950ec7176c4454a44d
+    persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
+    persistent-template-2.1.6-abb9add555d6012706d07d6768084389
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    shakespeare-2.0.7-299569683f963ce6b42dbe4d7cdb1dae
+    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    yesod-core-1.4.19-824bf74cd5ec378da568ce71e584e959
-    yesod-form-1.4.6-cc7fd5c2de84bb46c0f6247cd76452a8
-    yesod-persistent-1.4.0.3-cff443ae4acaed8c9376536a5719bdb9
+    yesod-core-1.4.19-42832ae56c3d48408d8da65a0e354ab2
+    yesod-form-1.4.6-e87deb06856da3fa0104c0eca2c57620
+    yesod-persistent-1.4.0.3-ca84b6eb145e15f51b714d496323d807
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
